import RPi.GPIO as GPIO
import time
import Adafruit_WS2801
import Adafruit_GPIO.SPI as SPI

GPIO.setmode(GPIO.BCM)
GPIO_TRIGGER = 18
GPIO_ECHO = 24

GPIO.setup(GPIO_TRIGGER, GPIO.OUT)
GPIO.setup(GPIO_ECHO, GPIO.IN)

PIXEL_COUNT = 32
SPI_PORT   = 0
SPI_DEVICE = 0
pixels = Adafruit_WS2801.WS2801Pixels(PIXEL_COUNT, spi=SPI.SpiDev(SPI_PORT, SPI_DEVICE))


def lights(order='up', mode='on'):
    start = 0
    stop = pixels.count()
    direction = 1  
    if order == 'down':
        start = 31
        stop = -1
        direction = -1
    hue = 0
    if mode == 'on':
        hue = 255
    for i in range(start, stop, direction):
        pixels.set_pixel(i, Adafruit_WS2801.RGB_to_color(hue, hue, hue))
        pixels.show()
        time.sleep(0.05)


def distanz():
    # setze Trigger auf HIGH
    GPIO.output(GPIO_TRIGGER, True)
 
    # setze Trigger nach 0.01ms aus LOW
    time.sleep(0.00001)
    GPIO.output(GPIO_TRIGGER, False)
 
    StartZeit = time.time()
    StopZeit = time.time()
 
    # speichere Startzeit
    while GPIO.input(GPIO_ECHO) == 0:
        StartZeit = time.time()
 
    # speichere Ankunftszeit
    while GPIO.input(GPIO_ECHO) == 1:
        StopZeit = time.time()
 
    # Zeit Differenz zwischen Start und Ankunft
    TimeElapsed = StopZeit - StartZeit
    # mit der Schallgeschwindigkeit (34300 cm/s) multiplizieren
    # und durch 2 teilen, da hin und zurueck
    distanz = (TimeElapsed * 34300) / 2
 
    return distanz


if __name__ == '__main__':
    try:
        while True:
            abstand = distanz()
            time.sleep(1.0)

            if distanz() < 40:
                print('Unter 8cm')
                pixels.clear()
                lights()
                # von unten nach oben Licht an
                time.sleep(2)
                lights(mode='off')
                # von unten nach oben Licht aus
                time.sleep(2)
                lights(order='down')
                # von oben nach unten Licht an
                time.sleep(2)
                lights(order='down', mode='off')
                # von oben nach unten Licht aus
                 
        # Beim Abbruch durch STRG+C resetten
    except KeyboardInterrupt:
        print("Messung vom User gestoppt")
        pixels.clear()
        GPIO.cleanup()
